@@ -55,7 +55,7 @@ class initializer():
 
     # call this method to see all collected datasets
     # it returns a list of dataframes
-    def show_data(self,of):
+    def show_data(self,of,daily=False):
         '''
         This method only assembles the collected data 
 
@@ -65,12 +65,20 @@ class initializer():
             returns collected data as 3 dataframe format.
 
         '''
-        if of.lower() == 'confirmed':
-            return self.csv_Confirmed
-        elif of.lower() =='recovered':
-            return self.csv_recovered
-        elif of.lower() =='death':
-            return self.csv_Death
+        if daily == False:
+            if of.lower() == 'confirmed':
+                return self.csv_Confirmed
+            elif of.lower() =='recovered':
+                return self.csv_recovered
+            elif of.lower() =='death':
+                return self.csv_Death
+        elif daily == True:
+            if of.lower() == 'confirmed':
+                return self.count_conf
+            elif of.lower() =='recovered':
+                return self.count_recover
+            elif of.lower() =='death':
+                return self.count_death
 
 class Demographic_overview(initializer):
     def __init__(self,init,silent=False):
@@ -366,8 +374,12 @@ class Data(initializer):
                               'Total Recovered', 'Total Death']
                 return df.drop(columns=['CODE'])
             else:
-                return {'Confirmed':self.count_conf,'Recovered':self.count_recover,
-                        'Death':self.count_death}
+                frame_dict={'Confirmed':self.count_conf.iloc[-1,:][1:],
+                            'Recovered':self.count_recover.iloc[-1,:][1:],
+                            'Deceased':self.count_death.iloc[-1,:][1:]}
+                df=pd.DataFrame(frame_dict).reset_index()
+                df.columns=['Date','Confirmed','Recovered','Deceased']
+                return df
         else:
             try:
                 try:
@@ -1102,29 +1114,3 @@ class visualizer(initializer):
         else:
             raise Exception('Startdate should be less than Enddate')
 
-    def plot_by_latitude(self,title=None):
-        '''
-        Gives the visualization of counts with respect to state latitudes
-
-        Parameters
-        ----------
-        title : Character, optional
-            Sets the title of the subplots. The default is None.
-
-        Returns
-        -------
-        3 subplots consisting latitude vs latitude confirmed,latitudes vs total recovered,latitudes vs total deceased.
-
-        '''
-        
-        newConf = self.csv_Confirmed.sort_values(by=['LATITUDE'])
-        newRec = self.csv_recovered.sort_values(by=['LATITUDE'])
-        newDeath = self.csv_Death.sort_values(by=['LATITUDE'])
-        latitude = newConf['LATITUDE'][:-1]
-        confirmed = newConf[newConf.columns[-1]][:-1]
-        recovered = newRec[newRec.columns[-1]][:-1]
-        death = newDeath[newDeath.columns[-1]][:-1]
-        if title != None:
-            self.__graph(latitude, confirmed, recovered, death, date=False,title=title)
-        else:
-            self.__graph(latitude, confirmed, recovered, death, date=False)
